pub struct MsgMigrateContract {
pub sender: AccountId,
pub contract: AccountId,
pub code_id: u64,
pub msg: Vec<u8>,
}Expand description
MsgMigrateContract runs a code upgrade/ downgrade for a smart contract
Fields
sender: AccountIdSender is the that actor that signed the messages
contract: AccountIdContract is the address of the smart contract
code_id: u64CodeID references the new WASM code
msg: Vec<u8>Msg json encoded message to be passed to the contract on migration