EnigmaUtils

Struct EnigmaUtils 

pub struct EnigmaUtils { /* private fields */ }
Use to encrypt/decrypt messages related to the compute module.

Implementations

Source

impl EnigmaUtils

pub fn new(seed: Option<[u8; 32]>, chain_id: &str) -> Result<Self, Error>

Creates a new EnigmaUtils instance with a seed and chain ID.

The chain_id is used to determine the appropriate IO public key.

If no seed is provided, a random seed will be generated.

Examples
use secretrs::utils::EnigmaUtils;

let utils = EnigmaUtils::new(None, "secret-4").expect("Failed to create EnigmaUtils");
pub fn from_io_key( seed: Option<[u8; 32]>, consensus_io_pubkey: [u8; 32], ) -> Self

Creates a new EnigmaUtils instance with a seed and IO public key.

The consensus_io_pubkey is manually provided instead of being derived from a chain ID.

If no seed is provided, a random seed will be generated.

Examples
let mut registration = RegistrationQueryClient::connect("GRPC_URL").await?;
let enclave_key_bytes = registration.tx_key(()).await?.into_inner().key;

let mut io_key = [0u8; 32];
io_key.copy_from_slice(&enclave_key_bytes[0..32]);

let utils = EnigmaUtils::from_io_key(None, io_key);
pub fn encrypt<M: Serialize>( &self, contract_code_hash: &str, msg: &M, ) -> Result<SecretMsg, Error>

Encrypts a message for a specific contract using the associated code hash.

The message must implement serde::Serialize. A 64-character hexadecimal string representing the code hash is prepended to the message before encryption. The resulting SecretMsg is a concatenation of nonce, public key, and ciphertext.

Examples
use secretrs::utils::EnigmaUtils;

let utils = EnigmaUtils::new(None, "secret-4").expect("Failed to create EnigmaUtils");
let contract_code_hash = "1234567890abcdef1234567890abcdef1234567890abcdef1234567890abcdef";
let msg = QueryMsg::HelloWorld;
let encrypted_msg = utils.encrypt(contract_code_hash, &msg).expect("Encryption failed");
let (nonce, pubkey, ciphertext) = encrypted_msg.into_parts();
pub fn decrypt( &self, nonce: &[u8; 32], ciphertext: &[u8], ) -> Result<Vec<u8>, Error>

Decrypts a message returned by the enclave.

This function decrypts responses using the same nonce that was used to encrypt the request.

Examples
let decrypted_bytes = utils.decrypt(&nonce, &response.data).expect("Decryption failed");
let decrypted_b64_string = String::from_utf8(decrypted_bytes).expect("Decoding error");
let decoded_bytes = BASE64_STANDARD.decode(decrypted_b64_string).expect("Decoding error");
let data = String::from_utf8(decoded_bytes).expect("Decoding error");
pub fn get_seed(&self) -> [u8; 32]

Get the seed used to derive the key pair.

pub fn get_pubkey(&self) -> [u8; 32]

Get the public key of the derived key pair.

pub fn get_tx_encryption_key(&self, nonce: &[u8; 32]) -> [u8; 32]

Get the encryption key for a specific tx, based on the nonce.