pub struct DelayedVestingAccount {
pub base_vesting_account: Option<BaseVestingAccount>,
}Expand description
DelayedVestingAccount implements the VestingAccount interface.
It vests all coins after a specific time, but non prior. In other words, it keeps them locked until a specified time.
Fields
base_vesting_account: Option<BaseVestingAccount>Base vesting account specification required for this vesting implementation.